pub struct AuthoritySet {
pub owners: HashSet<NodeId>,
pub delegates: HashMap<NodeId, AuthorityScope>,
pub revoked: HashSet<NodeId>,
}Expand description
Authority set - who can mutate a state atom
Fields
owners: HashSet<NodeId>Nodes with full authority
delegates: HashMap<NodeId, AuthorityScope>Nodes with delegated authority (with scope)
revoked: HashSet<NodeId>Explicitly revoked nodes
Implementations
Sourceimpl AuthoritySet
impl AuthoritySet
pub fn new() -> Self
pub fn with_owner(owner: NodeId) -> Self
Check if a node has authority to perform an operation
Sourcepub fn add_delegate(&mut self, node: NodeId, scope: AuthorityScope)
pub fn add_delegate(&mut self, node: NodeId, scope: AuthorityScope)
Add a delegate with limited scope
Sourcepub fn contains(&self, node: &NodeId) -> bool
pub fn contains(&self, node: &NodeId) -> bool
Check if a node is in the authority set (owner or delegate)
Sourcepub fn is_revoked(&self, node: &NodeId) -> bool
pub fn is_revoked(&self, node: &NodeId) -> bool
Check if a node is revoked